MoonPhaseName enum
The 8 standard lunar phases.
- Inheritance
- Available extensions
Values
- newMoon → const MoonPhaseName
- waxingCrescent → const MoonPhaseName
- firstQuarter → const MoonPhaseName
- waxingGibbous → const MoonPhaseName
- fullMoon → const MoonPhaseName
- waningGibbous → const MoonPhaseName
- lastQuarter → const MoonPhaseName
- waningCrescent → const MoonPhaseName
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MoonPhaseName> - A constant List of the values in this enum, in order of their declaration.